"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * PanResponder & native event descriptions
 * NATIVE_EVENT
 * - changedTouches - Array of all touch events that have changed since the last event
 * - identifier - The ID of the touch
 * - locationX - The X position of the touch, relative to the element
 * - locationY - The Y position of the touch, relative to the element
 * - pageX - The X position of the touch, relative to the root element
 * - pageY - The Y position of the touch, relative to the root element
 * - target - The node id of the element receiving the touch event
 * - timestamp - A time identifier for the touch, useful for velocity calculation
 * - touches - Array of all current touches on the screen
 *
 * GESTURE_STATE
 * - stateID - ID of the gestureState- persisted as long as there at least one touch on screen
 * - moveX - the latest screen coordinates of the recently-moved touch
 * - moveY - the latest screen coordinates of the recently-moved touch
 * - x0 - the screen coordinates of the responder grant
 * - y0 - the screen coordinates of the responder grant
 * - dx - accumulated distance of the gesture since the touch started
 * - dy - accumulated distance of the gesture since the touch started
 * - vx - current velocity of the gesture
 * - vy - current velocity of the gesture
 * - numberActiveTouches - Number of touches currently on screen
 */
const GestureHandler = ({
  onEndTouchEvents,
  onStartTouchEvents,
  onChangeTouchEvents
}) => {
  const pathRef = (0, _react.useRef)([]);
  const panResponder = (0, _react.useRef)(_reactNative.PanResponder.create({
    onStartShouldSetPanResponder: () => true,
    onStartShouldSetPanResponderCapture: () => true,
    onMoveShouldSetPanResponder: () => true,
    onMoveShouldSetPanResponderCapture: () => true,
    onPanResponderGrant: (e, gestureState) => {
      pathRef.current = [];
      onStartTouchEvents && onStartTouchEvents(e, gestureState);
    },
    onPanResponderMove: event => {
      pathRef.current.push({
        x: event.nativeEvent.locationX,
        y: event.nativeEvent.locationY
      });
      onChangeTouchEvents([...pathRef.current]);
    },
    onPanResponderRelease: () => {
      const points = [...pathRef.current];
      onChangeTouchEvents(points);
      onEndTouchEvents && onEndTouchEvents(points);
    }
  })).current;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: _reactNative.StyleSheet.absoluteFill
  }, panResponder.panHandlers));
};

var _default = GestureHandler;
exports.default = _default;
//# sourceMappingURL=gesture-responder.js.map